All of the people who have made at least one contribution to molfeat.
Authors are sorted alphabetically.

* Cas Wognum
* Hadrien Mary
* Honore Hounwanou
* Saurav Maheshkar
* Therence
* maclandrol
* rbyrne-momatx
